<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/entity/RArcEntity.cpp" line="+88"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+76"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+107"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="+103"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+79"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Keskipiste</translation>
    </message>
    <message>
        <location line="-2"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="-2"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="+115"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-2"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="+105"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="+104"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="+105"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-2"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="+91"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+89"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+92"/>
        <location line="+4"/>
        <location line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+76"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+82"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+70"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+106"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+77"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+88"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+77"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-15"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-6"/>
        <location line="+4"/>
        <location line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-16"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-15"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-6"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-16"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <source>Radius</source>
        <translation>Säde</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-9"/>
        <source>Start Angle</source>
        <translation>Aloituskulma</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>End Angle</source>
        <translation>Lopetuskulma</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>Reversed</source>
        <translation>Käänteinen</translation>
    </message>
    <message>
        <location line="+2"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+2"/>
        <source>Diameter</source>
        <translation>Halkaisija</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+9"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+2"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+3"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+10"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+2"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-11"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+2"/>
        <source>Length</source>
        <translation>Pituus</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <source>Total Length</source>
        <translation>Kokonaispituus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sweep Angle</source>
        <translation>Pyyhintäkulma</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <source>Area</source>
        <translation>Pinta-ala</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <source>Total Area</source>
        <translation>Kokonaisalue</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeDefinitionEntity.cpp" line="+89"/>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+89"/>
        <source>Tag</source>
        <translation>Tunniste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prompt</source>
        <translation>Kehote</translation>
    </message>
    <message>
        <location filename="../src/entity/RCircleEntity.cpp" line="-1"/>
        <source>Circumference</source>
        <translation>Ympärysmitta</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Line</source>
        <translation>Mittajana</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 1</source>
        <translation>Laajennuspiste 1</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 2</source>
        <translation>Laajennuspiste 2</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 Start</source>
        <translation>Viiva 1 alku</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 End</source>
        <translation>Viiva 1 loppu</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="+10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 Start</source>
        <translation>Viiva 2 alku</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 End</source>
        <translation>Viiva 2 loppu</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Arc</source>
        <translation>Kaaren mitoitus</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-6"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Chord Point</source>
        <translation>Jännekohta</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Far Chord Point</source>
        <translation>Loitonna jänneväliä</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-5"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Nollapiste</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate</source>
        <translation>Ordinaatta</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Defining Point</source>
        <translation>Määrittelevä piste</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Leader End Point</source>
        <translation>Johtava päätepiste</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimRotatedEntity.cpp" line="+121"/>
        <source>Dimension Angle</source>
        <translation>Mittakulma</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-8"/>
        <source>Label</source>
        <translation>Selite</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Tolerance</source>
        <translation>Sallittu poikkeama</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Upper Limit</source>
        <translation>Yläraja</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Lower Limit</source>
        <translation>Alaraja</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Definition Point</source>
        <translation>Määrityspiste</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Tekstin sijainti</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Flip First Arrow</source>
        <translation>Käännä ensimmäinen nuoli</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Flip Second Arrow</source>
        <translation>Käännä toinen nuoli</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Fixed Extension Line</source>
        <translation>Kiinteä laajennuslinja</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension Line Length</source>
        <translation>Laajennuslinjan pituus</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Auto Label</source>
        <translation>Automaattiset selitteet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Measured Value</source>
        <translation>Mitattu arvo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear Factor</source>
        <translation>Lineaarinen kerroin</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block Name</source>
        <translation>Lohkon nimi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Auto Label Position</source>
        <translation>Autom. selitteen sijainti</translation>
    </message>
    <message>
        <location filename="../src/entity/REllipseEntity.cpp" line="-17"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Major Point</source>
        <translation>Määräävä piste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ratio</source>
        <translation>Suhde</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start Parameter</source>
        <translation>Aloitusparametri</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Parameter</source>
        <translation>Lopetusparametri</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-9"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Point</source>
        <translation>Alkupiste</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Point</source>
        <translation>Päätepiste</translation>
    </message>
    <message>
        <location filename="../src/entity/RHatchEntity.cpp" line="-8"/>
        <source>Solid</source>
        <translation>Kiinteä</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Kuvio</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>From Entity</source>
        <translation>Kohteesta</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+14"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-11"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+2"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <source>Angle</source>
        <translation>Kulma</translation>
    </message>
    <message>
        <location line="+192"/>
        <source>Yes</source>
        <translation>Kyllä</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>No</source>
        <translation>Ei</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-191"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+2"/>
        <source>Scale</source>
        <translation>Mittakaava</translation>
    </message>
    <message>
        <location filename="../src/entity/RHatchEntity.cpp" line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+2"/>
        <location line="+1"/>
        <source>Vertex</source>
        <translation>Kärkipiste</translation>
    </message>
    <message>
        <location filename="../src/entity/RImageEntity.cpp" line="-18"/>
        <source>File</source>
        <translation>Tiedosto</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPointEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Sijainti</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>U</source>
        <translation>U</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width Factor</source>
        <translation>Leveyskerroin</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height Factor</source>
        <translation>Pituuskerroin</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width</source>
        <translation>Leveys</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height</source>
        <translation>Korkeus</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Fade</source>
        <translation>Häivytä</translation>
    </message>
    <message>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-4"/>
        <source>Arrow</source>
        <translation>Nuoli</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow Block</source>
        <translation>Nuolilohko</translation>
    </message>
    <message>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-9"/>
        <source>Polyline Pattern</source>
        <translation>Murtoviivan kuvio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Closed</source>
        <translation>Suljettu</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Bulge</source>
        <translation>Pullistuma</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Start Width</source>
        <translation>Aloitusleveys</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Width</source>
        <translation>Loppuleveys</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Width</source>
        <translation>Kokonaisleveys</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orientation</source>
        <translation>Suunta</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Base Angle</source>
        <translation>Peruskulma</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Size 1</source>
        <translation>Koko 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Size 2</source>
        <translation>Koko 2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Z</source>
        <translation>Kokonais Z</translation>
    </message>
    <message>
        <location filename="../src/entity/RRayEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Base Point</source>
        <translation>Peruspiste</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Second Point</source>
        <translation>Toinen piste</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Direction Vector</source>
        <translation>Suuntavektori</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+3"/>
        <source>Fixed Angle</source>
        <translation>Kiinteä kulma</translation>
    </message>
    <message>
        <location filename="../src/entity/RFaceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 1</source>
        <translation>Piste 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 2</source>
        <translation>Piste 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 3</source>
        <translation>Piste 3</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 4</source>
        <translation>Piste 4</translation>
    </message>
    <message>
        <location filename="../src/entity/RSplineEntity.cpp" line="-12"/>
        <source>Closed Periodic</source>
        <translation>Suljettu jakso</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translation>Aste</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Control Point</source>
        <translation>Kontrollipiste</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Fit Point</source>
        <translation>Sovituspiste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Knot Vector</source>
        <translation>Solmuvektori</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Knot</source>
        <translation>Solmu</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use Start Tangent</source>
        <translation>Käytä aloitustangenttia</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Tangent</source>
        <translation>Käynnistä tangentti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use End Tangent</source>
        <translation>Käytä lopputangenttia</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Tangent</source>
        <translation>Lopputangentti</translation>
    </message>
    <message>
        <source>Simple</source>
        <translation type="vanished">Yksinkertainen</translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="vanished">Teksti</translation>
    </message>
    <message>
        <source>Font Name</source>
        <translation type="vanished">Kirjasimen nimi</translation>
    </message>
    <message>
        <source>Text Height</source>
        <translation type="vanished">Tekstin korkeus</translation>
    </message>
    <message>
        <source>Text Angle</source>
        <translation type="vanished">Tekstin kulma</translation>
    </message>
    <message>
        <source>X Scale</source>
        <translation type="vanished">X mittakaava</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="vanished">Lihavoitu</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">Kursiivi</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation type="vanished">Riviväli</translation>
    </message>
    <message>
        <source>Alignment</source>
        <translation type="vanished">Tasaus</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="vanished">Vaakasuunta</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation type="vanished">Pystysuunta</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+1"/>
        <source>Invisible</source>
        <translation>Näkymätön</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="+141"/>
        <source>Arc Symbol Type</source>
        <translation>Kaaren symbolin tyyppi</translation>
    </message>
</context>
</TS>
